package com.glxp.mipsdl.admin.controller;

import com.glxp.mipsdl.admin.http.UBaseResponse;
import com.glxp.mipsdl.admin.http.UCloudBasicClient;
import com.glxp.mipsdl.admin.http.UCloudStockClient;
import com.glxp.mipsdl.admin.http.request.*;
import com.glxp.mipsdl.admin.http.response.*;
import com.glxp.mipsdl.admin.req.BillQueryRequest;
import com.glxp.mipsdl.admin.res.CustmandocResponse;
import com.glxp.mipsdl.admin.res.InvmandocResponse;
import com.glxp.mipsdl.admin.res.PageSimpleResponse;
import com.glxp.mipsdl.admin.res.PurchaseinResponse;
import com.glxp.mipsdl.admin.util.DateUtil;
import com.glxp.mipsdl.common.enums.ResultEnum;
import com.glxp.mipsdl.common.res.BaseResponse;
import com.glxp.mipsdl.common.util.ResultVOUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpHeaders;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@RestController
public class UCloudController {
    @Value("${U8_URL}")
    private String u8Url;
    @Value("${U8_UNIT_CODE}")
    private String unitCode;
    @Value("${U8_COPERATOR}")
    private String coperator;
    @Value("${U8_USER_CODE}")
    private String userCode;
    @Value("${U8_SYSTEM}")
    private String systemCode;
    @Value("${U8_TRANS_TYPE}")
    private String transType;
    @Value("${U8_PASSWD}")
    private String passwd;


    //客商管理查询
    @GetMapping("/uclooud/basic/custmandoc")
    public BaseResponse getCustmandoc(UCustmandocRequest uCustmandocRequest) {
        uCustmandocRequest.setUnitcode(unitCode);
        UBaseResponse<List<UCustmandocResponse>> response = new UCloudBasicClient(u8Url, getNewHeads()).custmandocQuery(uCustmandocRequest);
        if (response != null) {
            List<UCustmandocResponse> uCustmandocResponses = response.getData().getDatas();
            if (uCustmandocResponses != null && !uCustmandocResponses.isEmpty()) {
                List<CustmandocResponse> custmandocResponses = new ArrayList<>();
                for (UCustmandocResponse queryResponse : uCustmandocResponses) {
                    CustmandocResponse custmandocResponse = new CustmandocResponse();
                    custmandocResponse.setConaddr(queryResponse.getParentvo().getConaddr());
                    custmandocResponse.setCustcode(queryResponse.getParentvo().getCustcode());
                    custmandocResponse.setCustname(queryResponse.getParentvo().getCustname());
                    custmandocResponse.setMnecode(queryResponse.getParentvo().getMnecode());
                    custmandocResponse.setPhone1(queryResponse.getParentvo().getPhone1());
                    custmandocResponse.setLinkman1(queryResponse.getParentvo().getLinkman1());
                    custmandocResponses.add(custmandocResponse);
                }
                PageSimpleResponse<CustmandocResponse> pageSimpleResponse = new PageSimpleResponse<>();
                pageSimpleResponse.setTotal((long) response.getData().getAllcount());
                pageSimpleResponse.setList(custmandocResponses);
                return ResultVOUtils.success(pageSimpleResponse);
            }

        }


//        response
        return ResultVOUtils.success(response);
    }

    //存货管理档案查询
    @GetMapping("/uclooud/basic/invbasdoc")
    public BaseResponse getInvbasdoc(UInvmandocRequest uInvmandocRequest) {
        uInvmandocRequest.setUnitcode(unitCode);
        UBaseResponse<List<UInvmandocQueryResponse>> response = new UCloudBasicClient(u8Url, getNewHeads()).invmandocQuery(uInvmandocRequest);
        if (response != null && response.getData()!=null) {
            List<UInvmandocQueryResponse> uCustmandocResponses = response.getData().getDatas();
            if (uCustmandocResponses != null && !uCustmandocResponses.isEmpty()) {
                List<InvmandocResponse> custmandocResponses = new ArrayList<>();
                for (UInvmandocQueryResponse queryResponse : uCustmandocResponses) {
                    InvmandocResponse invmandocResponse = new InvmandocResponse();
                    invmandocResponse.setInvcode(queryResponse.getParentvo().getInvbasVo().getInvcode());
                    invmandocResponse.setInvname(queryResponse.getParentvo().getInvbasVo().getInvname());
                    invmandocResponse.setMeasname(queryResponse.getParentvo().getInvbasVo().getMeasname());
                    invmandocResponse.setInvspec(queryResponse.getParentvo().getInvbasVo().getInvspec());
                    invmandocResponse.setInvtype(queryResponse.getParentvo().getInvbasVo().getInvtype());
                    invmandocResponse.setProdarea(queryResponse.getParentvo().getInvmanVo().getProdarea());
                    custmandocResponses.add(invmandocResponse);
                }
                PageSimpleResponse<InvmandocResponse> pageSimpleResponse = new PageSimpleResponse<>();
                pageSimpleResponse.setTotal((long) response.getData().getAllcount());
                pageSimpleResponse.setList(custmandocResponses);
                return ResultVOUtils.success(pageSimpleResponse);
            }
        }else {
            return ResultVOUtils.error(500,response.getErrormsg());
        }
        return ResultVOUtils.success(response);
    }


    @GetMapping("/uclooud/basic/billQuery")
    public BaseResponse billQuery(BillQueryRequest billQueryRequest) {
        if (billQueryRequest.getBillAction().equals("PurchaseWareHouseIn") || billQueryRequest.getBillAction().equals("ReturnWareHouseOut")) {
            UPurchaseinRequest uPurchaseinRequest = new UPurchaseinRequest();
            BeanUtils.copyProperties(billQueryRequest, uPurchaseinRequest);
            return getPurchasein(uPurchaseinRequest);
        } else if (billQueryRequest.getBillAction().equals("SalesWareHouseOut") || billQueryRequest.getBillAction().equals("ReturnWareHouseIn")) {

            USaleoutQueryRequest uSaleoutQueryRequest = new USaleoutQueryRequest();
            BeanUtils.copyProperties(billQueryRequest, uSaleoutQueryRequest);
            return getSaleout(uSaleoutQueryRequest);
        } else {
            return ResultVOUtils.error(500, "单据类型错误！");
        }
    }


    //采购入库单查询
    @GetMapping("/uclooud/basic/purchasein_query")
    public BaseResponse getPurchasein(UPurchaseinRequest uPurchaseinRequest) {
        uPurchaseinRequest.setCorp(unitCode);
        UBaseResponse<List<UPurchaseinQueryResponse>> response = new UCloudStockClient(u8Url, getNewHeads()).purchaseinQuery(uPurchaseinRequest);
        if (response != null) {
            List<UPurchaseinQueryResponse> uPurchaseinQueryResponses = response.getData().getDatas();
            if (uPurchaseinQueryResponses != null && !uPurchaseinQueryResponses.isEmpty()) {
                List<PurchaseinResponse> purchaseinResponses = new ArrayList<>();
                for (UPurchaseinQueryResponse queryResponse : uPurchaseinQueryResponses) {
                    PurchaseinResponse purchaseinResponse = new PurchaseinResponse();
                    UPurchaseinQueryResponse.ParentvoBean parentvoBean = queryResponse.getParentvo();
                    if (parentvoBean != null) {
                        purchaseinResponse.setDbilldate(parentvoBean.getDbilldate());
                        purchaseinResponse.setProvider_code(parentvoBean.getProvider_code());
                        purchaseinResponse.setProvider_name(parentvoBean.getProvider_name());
                        purchaseinResponse.setVbillcode(parentvoBean.getVbillcode());
                        purchaseinResponse.setBillType("采购入库");
                        purchaseinResponse.setFreplenishflag(parentvoBean.isFreplenishflag());
                    }
                    List<UPurchaseinQueryResponse.ChildrenvoBean> childrenvoBeans = queryResponse.getChildrenvo();
                    if (childrenvoBeans != null && childrenvoBeans.size() > 0) {
                        List<PurchaseinResponse.SubPurchase> subPurchases = new ArrayList<>();
                        for (UPurchaseinQueryResponse.ChildrenvoBean childrenvoBean : childrenvoBeans) {
                            PurchaseinResponse.SubPurchase subPurchase = new PurchaseinResponse.SubPurchase();
                            subPurchase.setInventory_code(childrenvoBean.getInventory_code());
                            subPurchase.setInventory_name(childrenvoBean.getInventory_name());
                            subPurchase.setInvspec(childrenvoBean.getInvspec());
                            subPurchase.setNshouldinnum(childrenvoBean.getNshouldinnum());
                            subPurchase.setNinnum(childrenvoBean.getNinnum());
                            subPurchase.setDtlgoodsqty(childrenvoBean.getNinnum());
                            subPurchase.setReCount(childrenvoBean.getNshouldinnum());
                            subPurchase.setVbatchcode(childrenvoBean.getVbatchcode());
                            subPurchase.setDvalidate(childrenvoBean.getDvalidate());
                            subPurchases.add(subPurchase);
                        }
                        purchaseinResponse.setSubPurchases(subPurchases);
                    }
                    purchaseinResponses.add(purchaseinResponse);
                }
                PageSimpleResponse<PurchaseinResponse> pageSimpleResponse = new PageSimpleResponse<>();
                pageSimpleResponse.setTotal((long) response.getData().getAllcount());
                pageSimpleResponse.setList(purchaseinResponses);
                return ResultVOUtils.success(pageSimpleResponse);
            }
        }
        return ResultVOUtils.success(response);
    }

    //销售出库单查询
    @GetMapping("/uclooud/basic/saleout_query")
    public BaseResponse getSaleout(USaleoutQueryRequest uSaleoutQueryRequest) {
        uSaleoutQueryRequest.setCorp(unitCode);
        UBaseResponse<List<USaleoutQueryResponse>> response = new UCloudStockClient(u8Url, getNewHeads()).saleoutQuery(uSaleoutQueryRequest);
        if (response != null) {
            List<USaleoutQueryResponse> uSaleoutQueryResponses = response.getData().getDatas();
            if (uSaleoutQueryResponses != null && !uSaleoutQueryResponses.isEmpty()) {
                List<PurchaseinResponse> purchaseinResponses = new ArrayList<>();
                for (USaleoutQueryResponse queryResponse : uSaleoutQueryResponses) {
                    PurchaseinResponse purchaseinResponse = new PurchaseinResponse();
                    USaleoutQueryResponse.ParentvoBean parentvoBean = queryResponse.getParentvo();
                    if (parentvoBean != null) {
                        purchaseinResponse.setDbilldate(parentvoBean.getDbilldate());
                        purchaseinResponse.setProvider_code(parentvoBean.getCustomer_code());
                        purchaseinResponse.setProvider_name(parentvoBean.getCustomer_name());
                        purchaseinResponse.setVbillcode(parentvoBean.getVbillcode());
                        purchaseinResponse.setFreplenishflag(parentvoBean.isFreplenishflag());
                        purchaseinResponse.setBillType("销售出库");
                    }
                    List<USaleoutQueryResponse.ChildrenvoBean> childrenvoBeans = queryResponse.getChildrenvo();
                    if (childrenvoBeans != null && childrenvoBeans.size() > 0) {
                        List<PurchaseinResponse.SubPurchase> subPurchases = new ArrayList<>();
                        for (USaleoutQueryResponse.ChildrenvoBean childrenvoBean : childrenvoBeans) {
                            PurchaseinResponse.SubPurchase subPurchase = new PurchaseinResponse.SubPurchase();
                            subPurchase.setInventory_code(childrenvoBean.getInventory_code());
                            subPurchase.setInventory_name(childrenvoBean.getInventory_name());
                            subPurchase.setInvspec(childrenvoBean.getInvspec());
                            subPurchase.setNshouldinnum(childrenvoBean.getNshouldoutnum());
                            subPurchase.setNoutnum(childrenvoBean.getNoutnum());
                            subPurchase.setDtlgoodsqty(childrenvoBean.getNoutnum());
                            subPurchase.setReCount(childrenvoBean.getNshouldoutnum());
                            subPurchase.setVbatchcode(childrenvoBean.getVbatchcode());
                            subPurchases.add(subPurchase);
                        }
                        purchaseinResponse.setSubPurchases(subPurchases);
                    }
                    purchaseinResponses.add(purchaseinResponse);
                }
                PageSimpleResponse<PurchaseinResponse> pageSimpleResponse = new PageSimpleResponse<>();
                pageSimpleResponse.setTotal((long) response.getData().getAllcount());
                pageSimpleResponse.setList(purchaseinResponses);
                return ResultVOUtils.success(pageSimpleResponse);
            }
        }
        return ResultVOUtils.success(response);
    }

    //采购入库单签字
    @PostMapping("uclooud/basic/purchaseinSign")
    public BaseResponse purchaseinSign(@RequestBody USignRequest uSignRequest) {

        UPurhaseinSignRequest uPurhaseinSignRequest = new UPurhaseinSignRequest();
        UPurhaseinSignRequest.QueryInfoBean queryInfoBean = new UPurhaseinSignRequest.QueryInfoBean();
        Map date = DateUtil.getYearTRange();
        queryInfoBean.setDate_begin((String) date.get("startDate"));
        queryInfoBean.setDate_end((String) date.get("endDate"));
        queryInfoBean.setCalbody(unitCode);
        queryInfoBean.setCorp(unitCode);
        queryInfoBean.setBillcode(uSignRequest.getBillcode());
        uPurhaseinSignRequest.setQueryInfo(queryInfoBean);
        UPurhaseinSignRequest.SignInfoBean signInfoBean = new UPurhaseinSignRequest.SignInfoBean();
        signInfoBean.setCoperator(coperator);
        uPurhaseinSignRequest.setSignInfo(signInfoBean);
        UBaseResponse data = new UCloudStockClient(u8Url, getNewHeads()).purchaseinSign(uPurhaseinSignRequest);
        if (data != null && data.getStatus().equals("success")) {
            return ResultVOUtils.success("修改成功");
        } else {
            if (data != null) {
                return ResultVOUtils.error(500, data.getErrormsg());
            }
            return ResultVOUtils.error(500, "连接U8云下载服务出错！");
        }
    }

    @PostMapping("uclooud/basic/saleSign")
    public BaseResponse saleSign(@RequestBody USignRequest uSignRequest) {

        USaleoutSignRequest uSaleoutSignRequest = new USaleoutSignRequest();
        USaleoutSignRequest.QueryInfoBean queryInfoBean = new USaleoutSignRequest.QueryInfoBean();
        Map date = DateUtil.getYearTRange();
        queryInfoBean.setDate_begin((String) date.get("startDate"));
        queryInfoBean.setDate_end((String) date.get("endDate"));
        queryInfoBean.setCalbody(unitCode);
        queryInfoBean.setCorp(unitCode);
        queryInfoBean.setBillcode(uSignRequest.getBillcode());
        uSaleoutSignRequest.setQueryInfo(queryInfoBean);
        USaleoutSignRequest.SignInfoBean signInfoBean = new USaleoutSignRequest.SignInfoBean();
        signInfoBean.setCoperator(coperator);
        uSaleoutSignRequest.setSignInfo(signInfoBean);
        UBaseResponse data = new UCloudStockClient(u8Url, getNewHeads()).saleOutSign(uSaleoutSignRequest);
        if (data != null && data.getStatus().equals("success")) {
            return ResultVOUtils.success("修改成功");
        } else {
            if (data != null) {
                return ResultVOUtils.error(500, data.getErrormsg());
            }
            return ResultVOUtils.error(500, "连接U8云下载服务出错！");
        }
    }

    @PostMapping("uclooud/basic/modifyBill")
    public BaseResponse modifyBill(@RequestBody ModifyPruchaseinRequest modifyPruchaseinRequest) {
        if (modifyPruchaseinRequest.getBillAction().equals("PurchaseWareHouseIn") || modifyPruchaseinRequest.getBillAction().equals("ReturnWareHouseOut")) {
            return modifyPurchasein(modifyPruchaseinRequest);
        } else if (modifyPruchaseinRequest.getBillAction().equals("SalesWareHouseOut") || modifyPruchaseinRequest.getBillAction().equals("ReturnWareHouseIn")) {
            return modifySale(modifyPruchaseinRequest);
        } else {
            return ResultVOUtils.error(500, "单据类型错误！");
        }
    }


    //采购入库单修改
    @PostMapping("uclooud/basic/modifyPurchasein")
    public BaseResponse modifyPurchasein(@RequestBody ModifyPruchaseinRequest modifyPruchaseinRequest) {
        if (modifyPruchaseinRequest == null || modifyPruchaseinRequest.getGeneralBillVO() == null) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, "参数不能为null");
        }
        List<ModifyPruchaseinRequest.GeneralBillVOBean> generalBillVOBeans = modifyPruchaseinRequest.getGeneralBillVO();
        for (ModifyPruchaseinRequest.GeneralBillVOBean generalBillVOBean : generalBillVOBeans) {
            UPurchaseinRequest uPurchaseinRequest = new UPurchaseinRequest();
            uPurchaseinRequest.setBillcode(generalBillVOBean.getParentVO().getVbillcode());
            uPurchaseinRequest.setPage_size("1");
            uPurchaseinRequest.setPage_now("1");
            Map date = DateUtil.getYearTRange();
            uPurchaseinRequest.setDate_begin((String) date.get("startDate"));
            uPurchaseinRequest.setDate_end((String) date.get("endDate"));
            uPurchaseinRequest.setCorp(unitCode);
            UBaseResponse<List<UPurchaseinQueryResponse>> response = new UCloudStockClient(u8Url, getNewHeads()).purchaseinQuery(uPurchaseinRequest);

            List<UPurchaseinQueryResponse> uPurchaseinQueryResponses = response.getData().getDatas();
            if (uPurchaseinQueryResponses != null && !uPurchaseinQueryResponses.isEmpty()) {
                UPurchaseinQueryResponse uPurchaseinQueryResponse = uPurchaseinQueryResponses.get(0);
                UPurchaseinQueryResponse.ParentvoBean parentvoBean = uPurchaseinQueryResponse.getParentvo();
                generalBillVOBean.getParentVO().setCbiztype(parentvoBean.getBiztype_code());
                generalBillVOBean.getParentVO().setCoperatorid(parentvoBean.getOperator_code());
                generalBillVOBean.getParentVO().setCwarehouseid(parentvoBean.getWarehouseid_code());
                generalBillVOBean.getParentVO().setPk_calbody(unitCode);
                generalBillVOBean.getParentVO().setPk_corp(unitCode);
                generalBillVOBean.getParentVO().setVnote("扫码修改");
                generalBillVOBean.setChildrenVO(transChild(modifyPruchaseinRequest.getBillAction(), generalBillVOBean, uPurchaseinQueryResponse));
            }
        }
        modifyPruchaseinRequest.setGeneralBillVO(generalBillVOBeans);
        UBaseResponse data = new UCloudStockClient(u8Url, getNewHeads()).purchaseinModify(modifyPruchaseinRequest);
        if (data != null && data.getStatus().equals("success")) {
            return ResultVOUtils.success("修改成功");
        } else {
            if (data != null) {
                return ResultVOUtils.error(500, data.getErrormsg());
            }
            return ResultVOUtils.error(500, "连接U8云下载服务出错！");
        }


    }


    //销售出库单修改
    @PostMapping("uclooud/basic/modifySale")
    public BaseResponse modifySale(@RequestBody ModifyPruchaseinRequest modifyPruchaseinRequest) {
        if (modifyPruchaseinRequest == null || modifyPruchaseinRequest.getGeneralBillVO() == null) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, "参数不能为null");
        }
        List<ModifyPruchaseinRequest.GeneralBillVOBean> generalBillVOBeans = modifyPruchaseinRequest.getGeneralBillVO();
        for (ModifyPruchaseinRequest.GeneralBillVOBean generalBillVOBean : generalBillVOBeans) {
            USaleoutQueryRequest uPurchaseinRequest = new USaleoutQueryRequest();
            uPurchaseinRequest.setBillcode(generalBillVOBean.getParentVO().getVbillcode());
            uPurchaseinRequest.setPage_size("1");
            uPurchaseinRequest.setPage_now("1");
            Map date = DateUtil.getYearTRange();
            uPurchaseinRequest.setDate_begin((String) date.get("startDate"));
            uPurchaseinRequest.setDate_end((String) date.get("endDate"));
            uPurchaseinRequest.setCorp("1110");
            UBaseResponse<List<USaleoutQueryResponse>> response = new UCloudStockClient(u8Url, getNewHeads()).saleoutQuery(uPurchaseinRequest);

            List<USaleoutQueryResponse> uPurchaseinQueryResponses = response.getData().getDatas();
            if (uPurchaseinQueryResponses != null && !uPurchaseinQueryResponses.isEmpty()) {
                USaleoutQueryResponse uPurchaseinQueryResponse = uPurchaseinQueryResponses.get(0);
                USaleoutQueryResponse.ParentvoBean parentvoBean = uPurchaseinQueryResponse.getParentvo();
                generalBillVOBean.getParentVO().setCbiztype(parentvoBean.getBiztype_code());
                generalBillVOBean.getParentVO().setCoperatorid(parentvoBean.getOperator_code());
                generalBillVOBean.getParentVO().setCwarehouseid(parentvoBean.getWarehouseid_code());
                generalBillVOBean.getParentVO().setPk_calbody("1110");
                generalBillVOBean.getParentVO().setPk_corp("1110");
                generalBillVOBean.getParentVO().setVnote("校验修改");
                generalBillVOBean.getParentVO().setCcustomerid(parentvoBean.getCustomer_code());
                generalBillVOBean.setChildrenVO(transSaleChild(modifyPruchaseinRequest.getBillAction(), generalBillVOBean, uPurchaseinQueryResponse));
            }
        }
        modifyPruchaseinRequest.setGeneralBillVO(generalBillVOBeans);


        UBaseResponse data = new UCloudStockClient(u8Url, getNewHeads()).saleModify(modifyPruchaseinRequest);
        if (data != null && data.getStatus().equals("success")) {
            return ResultVOUtils.success("修改成功");
        } else {
            if (data != null) {
                return ResultVOUtils.error(500, data.getErrormsg());
            }
            return ResultVOUtils.error(500, "连接U8云下载服务出错！");
        }

    }


    //现存量查询
    @GetMapping("/uclooud/basic/onhandQuery")
    public BaseResponse onhandQuery(UOnhandQueryRequest onhandQueryRequest) {
        onhandQueryRequest.setCorp(unitCode);
        onhandQueryRequest.setCalbody(unitCode);
        UBaseResponse<List<UOnhandQueryResponse>> response = new UCloudStockClient(u8Url, getNewHeads()).onhandQuery(onhandQueryRequest);
        if (response != null) {
            List<UOnhandQueryResponse> uOnhandQueryResponses;
            uOnhandQueryResponses = response.getData().getDatas();
            PageSimpleResponse<UOnhandQueryResponse> pageSimpleResponse = new PageSimpleResponse<>();
            pageSimpleResponse.setTotal((long) response.getData().getAllcount());
            pageSimpleResponse.setList(uOnhandQueryResponses);
            return ResultVOUtils.success(pageSimpleResponse);
        }
        return ResultVOUtils.success(response);
    }

    @PostMapping("/uclooud/basic/onhandPost")
    public BaseResponse onhandPost(@RequestBody UOnhandPostQueryRequest onhandQueryRequest) {
        onhandQueryRequest.setCorp(unitCode);
        onhandQueryRequest.setCalbody(unitCode);

        UBaseResponse<List<UOnhandQueryResponse>> response = new UCloudStockClient(u8Url, getNewHeads()).onhandQueryPost(onhandQueryRequest);
        if (response != null) {
            List<UOnhandQueryResponse> uOnhandQueryResponses;
            uOnhandQueryResponses = response.getData().getDatas();
            PageSimpleResponse<UOnhandQueryResponse> pageSimpleResponse = new PageSimpleResponse<>();
            pageSimpleResponse.setTotal((long) response.getData().getAllcount());
            pageSimpleResponse.setList(uOnhandQueryResponses);
            return ResultVOUtils.success(pageSimpleResponse);
        }
        return ResultVOUtils.success(response);
    }


    public List<ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean> transChild
            (String action, ModifyPruchaseinRequest.GeneralBillVOBean generalBillVOBean, UPurchaseinQueryResponse uPurchaseinQueryResponse) {
        List<ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean> childrenVOBeans = generalBillVOBean.getChildrenVO();
        List<UPurchaseinQueryResponse.ChildrenvoBean> temps = uPurchaseinQueryResponse.getChildrenvo();
        if (childrenVOBeans != null && temps != null) {
            for (ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean childrenVOBean : childrenVOBeans) {
                for (int i = 0; i < temps.size(); i++) {
                    if (childrenVOBean.getCinventoryid().equals(temps.get(i).getInventory_code())) {
//                        childrenVOBean.setNprice(temps.get(i).getNprice() + "");
                        childrenVOBean.setCrowno(temps.get(i).getCrowno());
                        if (action.equals("ReturnWareHouseOut")) {
                            childrenVOBean.setNoutnum((-Integer.parseInt(childrenVOBean.getNinnum())) + "");
                        }
                    }
                }
            }
        }
        return childrenVOBeans;
    }

    public List<ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean> transSaleChild
            (String action, ModifyPruchaseinRequest.GeneralBillVOBean generalBillVOBean, USaleoutQueryResponse uSaleoutQueryResponse) {
        List<ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean> childrenVOBeans = generalBillVOBean.getChildrenVO();
        List<USaleoutQueryResponse.ChildrenvoBean> temps = uSaleoutQueryResponse.getChildrenvo();
        if (childrenVOBeans != null && temps != null) {
            for (ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean childrenVOBean : childrenVOBeans) {
                for (int i = 0; i < temps.size(); i++) {
                    if (childrenVOBean.getCinventoryid().equals(temps.get(i).getInventory_code())) {
//                        childrenVOBean.setNprice(temps.get(i).getNsaleprice() + "");
//                        childrenVOBean.setNoutnum(temps.get(i).getNoutnum() + "");
                        childrenVOBean.setCrowno(temps.get(i).getCrowno());
                        if (action.equals("ReturnWareHouseIn")) {
                            childrenVOBean.setNoutnum((-Integer.parseInt(childrenVOBean.getNoutnum())) + "");
                        }

                    }

                }
            }
        }
        return childrenVOBeans;
    }

    public HttpHeaders getNewHeads() {
        HttpHeaders headers = new HttpHeaders();
        headers.add("Content-Type", "application/json; charset=UTF-8");
        headers.add("system", systemCode);
        headers.add("usercode", userCode);
        headers.add("password", passwd);
        headers.add("trantype", transType);
        return headers;
    }
}
