package com.glxp.mipsdl.admin.thread;

import com.glxp.mipsdl.admin.entity.ErpStockEntity;
import com.glxp.mipsdl.admin.http.UBaseResponse;
import com.glxp.mipsdl.admin.http.UCloudStockClient;
import com.glxp.mipsdl.admin.http.request.UPurchaseinRequest;
import com.glxp.mipsdl.admin.http.response.UPurchaseinQueryResponse;
import com.glxp.mipsdl.admin.req.UdiwmsOrderRequest;
import com.glxp.mipsdl.admin.res.PageSimpleResponse;
import com.glxp.mipsdl.admin.res.UdiwmsOrderResponse;
import com.glxp.mipsdl.admin.service.InvErpStockService;
import com.glxp.mipsdl.admin.util.DateUtil;
import com.glxp.mipsdl.common.res.BaseResponse;
import com.glxp.mipsdl.common.util.ResultVOUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpHeaders;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Service
public class InvDlErpStockService {

    @Value("${U8_URL}")
    private String u8Url;
    @Value("${U8_UNIT_CODE}")
    private String unitCode;
    @Value("${U8_COPERATOR}")
    private String coperator;
    @Value("${U8_USER_CODE}")
    private String userCode;
    @Value("${U8_SYSTEM}")
    private String systemCode;
    @Value("${U8_TRANS_TYPE}")
    private String transType;
    @Value("${U8_PASSWD}")
    private String passwd;
    @Resource
    InvErpStockService erpStockService;
    final Logger logger = LoggerFactory.getLogger(InvDlErpStockService.class);

    /**
     * 下载ERP采购入库单所有产品信息到ERP库存表
     */
    @Async
    public void dlErpStock() {
        Map date = DateUtil.getDayRange(60);
        Integer page = 1;
        Integer limit = 20;
        while (true) {
            UdiwmsOrderRequest filterOrderRequest = new UdiwmsOrderRequest();
            filterOrderRequest.setPage(page);
            filterOrderRequest.setLimit(limit);
            filterOrderRequest.setStartDate((String) date.get("startDate"));
            filterOrderRequest.setEndDate((String) date.get("endDate"));
            filterOrderRequest.setBillAction("PurchaseWareHouseIn");
            BaseResponse<PageSimpleResponse<UdiwmsOrderResponse>> responseBaseResponse = getOrders(filterOrderRequest);
            if (responseBaseResponse.getCode() == 20000) {
                List<UdiwmsOrderResponse> erpOrderEntities = responseBaseResponse.getData().getList();
                List<ErpStockEntity> erpStockEntities = new ArrayList<>();
                if (erpOrderEntities != null && erpOrderEntities.size() > 0) {
                    page++;
                    for (UdiwmsOrderResponse erpOrderEntity : erpOrderEntities) {
                        //ERP数据更新
                        List<UdiwmsOrderResponse.SubErpOrder> subErpOrders = erpOrderEntity.getSubErpOrders();
                        if (subErpOrders != null && subErpOrders.size() > 0) {
                            for (UdiwmsOrderResponse.SubErpOrder subErpOrder : subErpOrders) {
                                ErpStockEntity erpStockEntity = new ErpStockEntity();
                                erpStockEntity.setOrderId(erpOrderEntity.getBillNo());
                                erpStockEntity.setCode(subErpOrder.getProductId());
                                erpStockEntity.setBatchNo(subErpOrder.getBatchNo());
                                erpStockEntity.setExpirationDate(subErpOrder.getExpireDate());
                                erpStockEntity.setName(subErpOrder.getProductName());
                                erpStockEntity.setCount(subErpOrder.getCount() + "");
                                erpStockEntities.add(erpStockEntity);
                                erpStockService.insertErpStocks(erpStockEntities);
                            }
                        }
                    }
                } else {
                    break;
                }
            }
            else {
                break;
            }

        }

    }

    public BaseResponse getOrders(UdiwmsOrderRequest udiwmsOrderRequest) {

        UPurchaseinRequest uPurchaseinRequest = new UPurchaseinRequest();
        uPurchaseinRequest.setDate_end(udiwmsOrderRequest.getEndDate());
        uPurchaseinRequest.setDate_begin(udiwmsOrderRequest.getStartDate());
        uPurchaseinRequest.setPage_now(udiwmsOrderRequest.getPage() + "");
        uPurchaseinRequest.setPage_size(udiwmsOrderRequest.getLimit() + "");
        // 3是已签字  2是未签字
        if ("0".equals(udiwmsOrderRequest.getBillFlag())) {
            uPurchaseinRequest.setFbillflag("2");
        } else if (("1").equals(udiwmsOrderRequest.getBillFlag())) {
            uPurchaseinRequest.setFbillflag("3");
        }
        uPurchaseinRequest.setBillcode(udiwmsOrderRequest.getBillNo());
        List<UdiwmsOrderResponse> udiwmsOrderResponses = getPurchasein(uPurchaseinRequest);
        if (udiwmsOrderResponses != null && udiwmsOrderResponses.size() > 0) {
            List<UdiwmsOrderResponse> returnsList = new ArrayList<>();
            if ("PurchaseWareHouseIn".equals(udiwmsOrderRequest.getBillAction())) {
                for (int i = 0; i < udiwmsOrderResponses.size(); i++) {
                    if (udiwmsOrderResponses.get(i).getBillType().equals("采购入库")) {
                        returnsList.add(udiwmsOrderResponses.get(i));
                    }
                }
            } else if ("ReturnWareHouseOut".equals(udiwmsOrderRequest.getBillAction())) {
                for (int i = 0; i < udiwmsOrderResponses.size(); i++) {
                    if (udiwmsOrderResponses.get(i).getBillType().equals("退货出库")) {
                        returnsList.add(udiwmsOrderResponses.get(i));
                    }
                }
            } else if ("WareHouseIn".equals(udiwmsOrderRequest.getAction())) {
                returnsList.addAll(udiwmsOrderResponses);
            }
            PageSimpleResponse<UdiwmsOrderResponse> pageSimpleResponse = new PageSimpleResponse<>();
            pageSimpleResponse.setTotal((long) returnsList.size());
            pageSimpleResponse.setList(returnsList);
            return ResultVOUtils.success(pageSimpleResponse);
        } else
            return ResultVOUtils.error(500, "未查询到数据");

    }


    public List<UdiwmsOrderResponse> getPurchasein(UPurchaseinRequest uPurchaseinRequest) {
        uPurchaseinRequest.setCorp(unitCode);
        UBaseResponse<List<UPurchaseinQueryResponse>> response = new UCloudStockClient(u8Url, getNewHeads()).purchaseinQuery(uPurchaseinRequest);
        if (response != null) {
            List<UPurchaseinQueryResponse> uPurchaseinQueryResponses = response.getData().getDatas();
            if (uPurchaseinQueryResponses != null && !uPurchaseinQueryResponses.isEmpty()) {
                List<UdiwmsOrderResponse> purchaseinResponses = new ArrayList<>();
                for (UPurchaseinQueryResponse queryResponse : uPurchaseinQueryResponses) {
                    UdiwmsOrderResponse udiwmsOrderResponse = new UdiwmsOrderResponse();
                    UPurchaseinQueryResponse.ParentvoBean parentvoBean = queryResponse.getParentvo();
                    if (parentvoBean != null) {
                        udiwmsOrderResponse.setBilldate(parentvoBean.getDbilldate());
                        udiwmsOrderResponse.setCorpId(parentvoBean.getProvider_code());
                        udiwmsOrderResponse.setCorpName(parentvoBean.getProvider_name());
                        udiwmsOrderResponse.setBillNo(parentvoBean.getVbillcode());
                        udiwmsOrderResponse.setSignFlag(parentvoBean.getFbillflag());
                        if (parentvoBean.isFreplenishflag())
                            udiwmsOrderResponse.setBillType("退货出库");
                        else
                            udiwmsOrderResponse.setBillType("采购入库");
                    }
                    List<UPurchaseinQueryResponse.ChildrenvoBean> childrenvoBeans = queryResponse.getChildrenvo();
                    if (childrenvoBeans != null && childrenvoBeans.size() > 0) {
                        List<UdiwmsOrderResponse.SubErpOrder> subPurchases = new ArrayList<>();
                        for (UPurchaseinQueryResponse.ChildrenvoBean childrenvoBean : childrenvoBeans) {
                            UdiwmsOrderResponse.SubErpOrder subErpOrder = new UdiwmsOrderResponse.SubErpOrder();
                            subErpOrder.setProductId(childrenvoBean.getInventory_code());
                            subErpOrder.setProductName(childrenvoBean.getInventory_name());
                            subErpOrder.setSpec(childrenvoBean.getInvspec());
                            subErpOrder.setCount(childrenvoBean.getNinnum());
                            subErpOrder.setReCount(childrenvoBean.getNshouldinnum());
                            subErpOrder.setBatchNo(childrenvoBean.getVbatchcode());
                            subErpOrder.setExpireDate(childrenvoBean.getDvalidate());
                            subPurchases.add(subErpOrder);
                        }
                        udiwmsOrderResponse.setSubErpOrders(subPurchases);
                    }
                    purchaseinResponses.add(udiwmsOrderResponse);
                }
                return purchaseinResponses;
            }
        }
        return null;
    }

    public HttpHeaders getNewHeads() {
        HttpHeaders headers = new HttpHeaders();
        headers.add("Content-Type", "application/json; charset=UTF-8");
        headers.add("system", systemCode);
        headers.add("usercode", userCode);
        headers.add("password", passwd);
        headers.add("trantype", transType);
        return headers;
    }
}
